@@ -2,7 +2,8 @@
     qgpgmekeyformailboxjob.cpp
 
     This file is part of qgpgme, the Qt API binding for gpgme
-    Copyright (c) 2016 Intevation GmbH
+    Copyright (c) 2016 by Bundesamt für Sicherheit in der Informationstechnik
+    Software engineering by Intevation GmbH
 
     QGpgME is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -30,6 +31,10 @@
     your version.
 */
 
+#ifdef HAVE_CONFIG_H
+ #include "config.h"
+#endif
+
 #include "qgpgmekeyformailboxjob.h"
 #include "qgpgmekeylistjob.h"
 
@@ -66,7 +71,7 @@ static bool subkeyIsOk(const Subkey s)
 static QGpgMEKeyForMailboxJob::result_type do_work(Context *ctx, const QString &mailbox, bool canEncrypt)
 {
     /* Do a Keylisting. */
-    ctx->setKeyListMode(GpgME::Extern | GpgME::Local | GpgME::Signatures | GpgME::Validate);
+    ctx->setKeyListMode(GpgME::Locate | GpgME::Signatures | GpgME::Validate);
     std::vector<Key> keys;
     QGpgMEKeyListJob *keylist = new QGpgMEKeyListJob(ctx);
 
